==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/elasticsearch/kotlin/inputs/DomainAutoTuneOptionsMaintenanceScheduleDurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticsearch.kotlin.inputs

import com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property unit The unit of time specifying the duration of an Auto-Tune maintenance window. Valid values: `HOURS`.
 * @property value An integer specifying the value of the duration of an Auto-Tune maintenance window.
 */
public data class DomainAutoTuneOptionsMaintenanceScheduleDurationArgs(
    public val unit: Output<String>,
    public val `value`: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs> {
    override fun toJava():
        com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs =
        com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs.builder()
            .unit(unit.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainAutoTuneOptionsMaintenanceScheduleDurationArgs].
 */
@PulumiTagMarker
public class DomainAutoTuneOptionsMaintenanceScheduleDurationArgsBuilder internal constructor() {
    private var unit: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value The unit of time specifying the duration of an Auto-Tune maintenance window. Valid values: `HOURS`.
     */
    @JvmName("mkxavssrhwrsduok")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value An integer specifying the value of the duration of an Auto-Tune maintenance window.
     */
    @JvmName("qqniodivqeafivux")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value The unit of time specifying the duration of an Auto-Tune maintenance window. Valid values: `HOURS`.
     */
    @JvmName("xboegtojklgwrjwo")
    public suspend fun unit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    /**
     * @param value An integer specifying the value of the duration of an Auto-Tune maintenance window.
     */
    @JvmName("iwqxeqkjxshdqvga")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): DomainAutoTuneOptionsMaintenanceScheduleDurationArgs =
        DomainAutoTuneOptionsMaintenanceScheduleDurationArgs(
            unit = unit ?: throw PulumiNullFieldException("unit"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/elasticsearch/kotlin/inputs/DomainAutoTuneOptionsMaintenanceScheduleDurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticsearch.kotlin.inputs

import com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property unit The unit of time specifying the duration of an Auto-Tune maintenance window. Valid values: `HOURS`.
 * @property value An integer specifying the value of the duration of an Auto-Tune maintenance window.
 */
public data class DomainAutoTuneOptionsMaintenanceScheduleDurationArgs(
    public val unit: Output<String>,
    public val `value`: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs> {
    override fun toJava(): com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs =
        com.pulumi.aws.elasticsearch.inputs.DomainAutoTuneOptionsMaintenanceScheduleDurationArgs.builder()
            .unit(unit.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainAutoTuneOptionsMaintenanceScheduleDurationArgs].
 */
@PulumiTagMarker
public class DomainAutoTuneOptionsMaintenanceScheduleDurationArgsBuilder internal constructor() {
    private var unit: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value The unit of time specifying the duration of an Auto-Tune maintenance window. Valid values: `HOURS`.
     */
    @JvmName("jgeehjkqxqxccrgy")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value An integer specifying the value of the duration of an Auto-Tune maintenance window.
     */
    @JvmName("mpoyuffmttjlisph")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value The unit of time specifying the duration of an Auto-Tune maintenance window. Valid values: `HOURS`.
     */
    @JvmName("rxpeskmlulitcyjg")
    public suspend fun unit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    /**
     * @param value An integer specifying the value of the duration of an Auto-Tune maintenance window.
     */
    @JvmName("qhunreulxqecnbue")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): DomainAutoTuneOptionsMaintenanceScheduleDurationArgs =
        DomainAutoTuneOptionsMaintenanceScheduleDurationArgs(
            unit = unit ?: throw PulumiNullFieldException("unit"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}
